@@ -694,6 +694,7 @@ static int ntpd_receive_response (int req_code, int *res_items, int *res_size,
 				(items_num + pkt_item_num) * res_item_size);
 		items = realloc ((void *) *res_data,
 				(items_num + pkt_item_num) * res_item_size);
+		items_num += pkt_item_num;
 		if (items == NULL)
 		{
 			items = *res_data;
@@ -881,7 +882,7 @@ static void ntpd_read (void)
 		struct info_peer_summary *ptr;
 		double offset;
 
-		char peername[512];
+		char peername[NI_MAXHOST];
 		int refclock_id;
 		
 		ptr = ps + i;
@@ -897,8 +898,15 @@ static void ntpd_read (void)
 
 		if (ptr->v6_flag)
 		{
-			status = getnameinfo ((const struct sockaddr *) &ptr->srcadr6,
-					sizeof (ptr->srcadr6),
+			struct sockaddr_in6 sa;
+
+			memset (&sa, 0, sizeof (sa));
+			sa.sin6_family = AF_INET6;
+			sa.sin6_port = htons (123);
+			memcpy (&sa.sin6_addr, &ptr->srcadr6, sizeof (struct in6_addr));
+
+			status = getnameinfo ((const struct sockaddr *) &sa,
+					sizeof (sa),
 					peername, sizeof (peername),
 					NULL, 0, 0 /* no flags */);
 			if (status != 0)
